package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````""4```````!``````````)@!`0``
M`````@```$``.``)`$``&P`:``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````1`````````!$``````````0`````````!````
M!0````````````````````````````````````RV````````#+8`````````
M``$```````$````&````H/H```````"@^@$``````*#Z`0``````X`4`````
M```(%@```````````0```````@````8```#0^@```````-#Z`0``````T/H!
M```````P`@```````#`"````````"``````````$````!````$P"````````
M3`(```````!,`@```````$0`````````1``````````$`````````%#E=&0$
M````M*X```````"TK@```````+2N````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````*#Z````````H/H!``````"@^@$`
M`````&`%````````8`4````````!`````````"]L:6(V-"]L9#8T+G-O+C(`
M````!````!0````#````1TY5`$Q$1EZM6V9`%EK`1N*_#Y[M:\O/!````!``
M```!````1TY5```````#````"@`````````1````20````0````(````(!`0
M``5`!(0H`@`$@(8`A(()```)(`0(B*`01;H``@@`````20```$P```!/````
M4````%<```!8````60```%L```!<````7@```%\```!@````80```&,`````
M`````````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+
MX\!"^M>'PN4_++KCDGS[H6Q@:PE#UF>OS&9"1=7LB0=PTPT4XIXR8MOMV\WC
MGA6,)<P-.I<+?ZF<F^"G`@IK&IY0H^#[20``````````````````````````
M```````````#``L`H!H````````````````````````#`!<````"````````
M`````````-P````28````````````````````````.0!```28```````````
M`````````````(,````28````````````````````````-$````1````````
M`````````````````+X"```28````````````````````````%4!```28```
M`````````````````````)L!```28`````````````````````````X"```2
M8````````````````````````/(````28`````````````````````````$`
M```@`````````````````````````'$"```28```````````````````````
M```"```28````````````````````````*8#```28```````````````````
M`````",!```28````````````````````````!,!```28```````````````
M`````````#X"```28`````````````````````````4!```28```````````
M`````````````/$!```28````````````````````````+T!```28```````
M`````````````````($"```28````````````````````````(L"```B8```
M`````````````````````!`````@`````````````````````````","```2
M8````````````````````````',!```28````````````````````````"P`
M```@`````````````````````````,H!```28```````````````````````
M`,(!```28````````````````````````$8"```28```````````````````
M`````+`"```28````````````````````````&,"```1````````````````
M`````````$8````28````````````````````````$4!```28```````````
M`````````````&,````28````````````````````````"H"```28```````
M`````````````````,`````28````````````````````````'0````28```
M`````````````````````&H"```28````````````````````````'X!```2
M8````````````````````````-H"```28````````````````````````(\!
M```28````````````````````````#`"```28```````````````````````
M`*0````28````````````````````````-,!```28```````````````````
M`````#<!```28````````````````````````&P!```28```````````````
M`````````.8````28````````````````````````$4"```28```````````
M`````````````+<"```28````````````````````````$T"```28```````
M`````````````````%L"```28`````````````````````````<"```28```
M`````````````````````(\````28````````````````````````'H"```2
M8````````````````````````&`!```28````````````````````````.L!
M```28````````````````````````/D!```28```````````````````````
M`+,````1`````````````````````````.$````28```````````````````
M`````*,!```28````````````````````````"P!```28```````````````
M`````````%0````28````````````````````````*@"```28```````````
M`````````````+<!```28````````````````````````-`"```1````````
M`````````````````)0!```28````````````````````````-$"```A````
M`````````````````````!4"```28````````````````````````)H"```2
M8````````````````````````-("```1`````````````````````````!P"
M```28````````````````````````*\#```28`P`@$\```````#$`0``````
M`!0$```28`P`\$````````!L"P```````,L"```28`P`0"(```````#(`@``
M`````!8#```28`P`<#$````````8`````````$0#```28`P`8$P````````@
M`P```````#H$```28`P`D#$```````!8!````````/H#```0`!@`@``"````
M`````````````"<#```2``P`\#4````````\`````````%H#```28`P`H#X`
M``````#``````````+L#```1``X`0&X````````$`````````-<#```28`P`
MT&<````````$`@```````.(#```28`P`\"\```````!D``````````\$```0
M`!@`J!`"`````````````````"@$```28`P`L#\````````X`0```````,H#
M```0`!<````"`````````````````'X#```28`P`,#8```````!\`@``````
M`"$$```0`!<`@``"`````````````````$<$```1`!<`>``"```````(````
M`````#0#```2``P`H&P````````0`````````-`#```28`P`""4```````!$
M`````````.H#```28`P`X&L```````"T``````````8$```28`P`,&<`````
M``"4`````````,P#```@`!<````"`````````````````)0#```28`P`8#\`
M``````!,`````````&@#```28`P`8#`````````$`0```````(H#```28`P`
MX&D```````#T`0```````%$$```28`P`L#@```````#L!0````````!?7V=M
M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R
M96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?
M<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!?7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC
M;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E
M=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`;'-T870V-`!?
M7W-T<FYC<'E?8VAK`&]P96YD:7(`<W1D97)R`&=E='5I9`!R96%D;&EN:P!S
M=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`
M;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV
M:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L:6)P97)L+G-O+C4N,S0`;&EB<'1H
M<F5A9"YS;RXP`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E
M;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A
M<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE
M`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X
M<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?
M96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ-P!'
M3$E"0U\R+C,S``````````$``@`!``$``@`!``,``@`!``$``@`"``(``0`!
M``(``0`"``(``@`"``$``@`!``$``@`"``0``@`"``$``0`!``(``0`!``(`
M`P`"``,``@`!``(``0`"``$`!``"``(``@`"``$``@`!``(``@`!``(``P`!
M``$``@`#``(``P`"``(``@`"``(``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$```````$``0#\`@``$```
M`"````"7D98&```#`%X$`````````0`"``P#```0`````````+.1E@8```0`
M:00``!````"7D98&```"`%X$````````H/H!```````6`````````)`F````
M````J/H!```````6`````````"`F````````N/H!```````6`````````$`B
M````````P/H!```````6`````````.!K````````R/H!```````6````````
M`*!L````````$/\!```````6`````````+#Z`0``````"``"```````6````
M``````@``@``````&``"```````6`````````/!Q````````(``"```````6
M`````````+!N````````,``"```````6`````````*!O````````.``"````
M```6`````````-!Q````````0``"```````6`````````-AQ````````2``"
M```````6`````````.!Q````````4``"```````6`````````.AQ````````
M8``"```````6`````````+AQ````````:``"```````6`````````,!Q````
M````>``"```````6`````````/AQ````````"/\!```````F````#```````
M````````&/\!```````F````&```````````````(/\!```````F````&P``
M````````````*/\!```````F````%P``````````````,/\!```````F````
M1P``````````````./\!```````F````!@``````````````0/\!```````F
M````(@``````````````2/\!```````F````(```````````````4/\!````
M```F````"P``````````````6/\!```````F````(P``````````````8/\!
M```````F````.P``````````````*/T!```````5`````P``````````````
M,/T!```````5````!```````````````./T!```````5````!0``````````
M````0/T!```````5````!P``````````````2/T!```````5````"```````
M````````4/T!```````5````"0``````````````6/T!```````5````"@``
M````````````8/T!```````5````#```````````````:/T!```````5````
M#0``````````````</T!```````5````#@``````````````>/T!```````5
M````#P``````````````@/T!```````5````$```````````````B/T!````
M```5````$0``````````````D/T!```````5````$@``````````````F/T!
M```````5````$P``````````````H/T!```````5````%```````````````
MJ/T!```````5````%0``````````````L/T!```````5````%@``````````
M````N/T!```````5````%P``````````````P/T!```````5````&0``````
M````````R/T!```````5````&@``````````````T/T!```````5````'```
M````````````V/T!```````5````'0``````````````X/T!```````5````
M'@``````````````Z/T!```````5````'P``````````````\/T!```````5
M````(0``````````````^/T!```````5````)````````````````/X!````
M```5````)0``````````````"/X!```````5````)@``````````````$/X!
M```````5````)P``````````````&/X!```````5````*```````````````
M(/X!```````5````*0``````````````*/X!```````5````*@``````````
M````,/X!```````5````*P``````````````./X!```````5````+```````
M````````0/X!```````5````+0``````````````2/X!```````5````+@``
M````````````4/X!```````5````+P``````````````6/X!```````5````
M,```````````````8/X!```````5````,0``````````````:/X!```````5
M````,@``````````````</X!```````5````,P``````````````>/X!````
M```5````-```````````````@/X!```````5````-0``````````````B/X!
M```````5````-@``````````````D/X!```````5````-P``````````````
MF/X!```````5````.```````````````H/X!```````5````.0``````````
M````J/X!```````5````.@``````````````L/X!```````5````/```````
M````````N/X!```````5````/0``````````````P/X!```````5````/@``
M````````````R/X!```````5````/P``````````````T/X!```````5````
M0```````````````V/X!```````5````00``````````````X/X!```````5
M````0P``````````````Z/X!```````5````10``````````````\/X!````
M```5````1@``````````````^/X!```````5````2```````````````````
M````````````````````````````&`!!^/__@CU@?HSII@.)?2`$@$X`````
M```````````"`$P\0&1".*8""'P0``'XH?\A^````&`(@`+H``"@+PP`_D&]
M__]+&`!!Z&``(3@0``'HI@,(?"``@$X`````&`!!^/__@CV8?XSII@.)?2`$
M@$X````````````````8`$'X__^"/7A_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]X'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CVH?XSI
MI@.)?2`$@$X````````````````8`$'X__^"/7A^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]B'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CTH?HSII@.)?2`$@$X````````````````8`$'X__^"/?!^C.FF`XE](`2`
M3@```````````````!@`0?C__X(]D'Z,Z:8#B7T@!(!.````````````````
M&`!!^/__@CU8?XSII@.)?2`$@$X````````````````8`$'X__^"/6A^C.FF
M`XE](`2`3@```````````````!@`0?C__X(].'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CTX?XSII@.)?2`$@$X````````````````8`$'X__^"
M/;!_C.FF`XE](`2`3@```````````````!@`0?C__X(]8'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CV@?HSII@.)?2`$@$X````````````````8
M`$'X__^"/>!_C.FF`XE](`2`3@```````````````!@`0?C__X(]$'^,Z:8#
MB7T@!(!.````````````````&`!!^/__@CW0?XSII@.)?2`$@$X`````````
M```````8`$'X__^"/>A_C.FF`XE](`2`3@```````````````!@`0?C__X(]
M,'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW(?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/7!^C.FF`XE](`2`3@```````````````!@`
M0?C__X(]T'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CW`?HSII@.)
M?2`$@$X````````````````8`$'X__^"/9!_C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]*'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV@
M?XSII@.)?2`$@$X````````````````8`$'X__^"/;!^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]V'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CT8?XSII@.)?2`$@$X````````````````8`$'X__^"/4!_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]V'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CT(?XSII@.)?2`$@$X````````````````8`$'X__^"/6A_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]B'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CU`?HSII@.)?2`$@$X````````````````8`$'X
M__^"/;A^C.FF`XE](`2`3@```````````````!@`0?C__X(]Z'Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CWX?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/2!_C.FF`XE](`2`3@```````````````!@`0?C__X(]2'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CW`?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/8!^C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]2'^,Z:8#B7T@!(!.````````````````&`!!^/__@CU0?HSII@.)?2`$
M@$X````````````````8`$'X__^"/0!_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]N'^,Z:8#B7T@!(!.````````````````&`!!^/__@CWX?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/<A^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]F'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CU8?HSII@.)?2`$@$X````````````````8`$'X__^"/7!_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]\'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CVH?HSII@.)?2`$@$X````````````````8`$'X__^"/5!_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]@'^,Z:8#B7T@!(!.````````
M````````&`!!^/__@CTP?HSII@.)?2`$@$X````````````````"`$P\P%Q"
M.*8""'SP_\'[^/_A^W@;:7P0``'X8?\A^'``@?AH`*'X<`"!.&@`H3A\`"&1
M?`!A./"/+>F(`"'Y```@.1W[_TL8`$'H````8%"`HN@```!@6(!BZ'@KI'P9
M2@!(````8````&!@@"+I``#)BP``'BR4`8)!````8#B`XNL``'^`&?[_2Q@`
M0>AX&VE\``!_@/H%28D"`$IA^@5)F?W]_TL8`$'H?`#A@_H%0XEX&VE\!`!_
M.`,`_SNT!V-\`0!*820?8WCZ!4F9\??_2Q@`0>A\`(&`<``!Z0```&!X@>+H
M_O^B//[_0CVH\J4XL/)*.7@;9GP```!@`0`$+```*.F0D<+X"`"F^!``YO@8
M`$;Y```F^80!@4#__R0Y!`!`.2``*7FF`RE]````8````&````!@``!"8`D`
MZ.BT!TE])!\I>0$`2CDJ2>9\[/\`0@,`)#FT!RE]``!`.0```&"@D6+H)!\I
M>?[_@CRT!^5_``#@."I)1GU`L(0X7?S_2Q@`0>@```,L>!M_?+0`@D$```!@
MH)%BZ(0`P3N=_/]+&`!!Z/[_8CQX\\1_,/!C.+$"`$@``",LH`""00```&"@
MD6+HM??_2Q@`0>C-]_]+&`!!Z+0'XW^(`$'I\(\MZ7E*2GT``"`YQ`""0*``
M(3@0``'H\/_!Z_C_X>NF`PA\(`"`3M7\_TL8`$'H````8```(RR@D6+XB`""
M0;WZ_TL8`$'H````8#B`XNL``'^`:?S_2Q@`0>BG"\.;0/[_2P```&"@D6+H
MT?O_2Q@`0>AX&W]\//__2P```&"8D6+H```C+`P`@D'9*@!(4/__2_[_8CQX
M\\1_N.]C..4!`$@```!@```C+)B18O@P_X)!L2H`2"C__TL$`"`YN/[_2P$`
M8#C5_/]+&`!!Z.WY_TL8`$'H``````````&``@```@!,//A90CAX"RE\Y`8A
M>````#B!_R'XI@,(?````?@0@`+I5/K_2P```&```````````$`@#``L````
M!@!?<W1A<G0```!@`@!,/+!90C@```!@````8("!8CB`@2(Y`!@I?"``@DT`
M``!@&(""Z0``+"P@`()-I@((?*8#B7T0``'XX?\A^!@`0?@A!(!.&`!!Z"``
M(3@0``'HI@,(?"``@$X``$)@`@!,/%!90C@```!@````8("!8CB`@8(X4""#
M?'0>A'QT#H1\E0&$?"``@DT```!@((""Z0``+"P@`()-I@((?*8#B7T0``'X
MX?\A^!@`0?@A!(!.&`!!Z"``(3@0``'HI@,(?"``@$X```!@``!"8`(`3#S@
M6$(X````8("!(HD```DL(`""3*8""'P```!@*(`BZ0``*2P0``'XX?\A^!0`
M@D$```!@"(%BZ$7Y_TL8`$'H]?[_2R``(3@!`"`Y````8!```>B`@2*9I@,(
M?"``@$X```!@````8```0F`"`$P\<%A"."#__TL```!@`@!,/&!80CC@_X'[
M>1M\?/C_X?NQ_R'X``&"02@`8?L```!@,(`BZ0``:>L``#LL\`""02``0?M`
M`,'[>".:?'CCGG\``#R)```)+.``@D$]``DL'`""00$`/HT```DL\/^"0```
M`&````!@``!"8%#PW'\``/OK```_++@`@D&F`@A\.`"A^[0'WG]XVWU_8``!
M^````&````!@``!"8'CSQ7]XXX1_>/OC?U7W_TL8`$'H```#+!``@D"N\#]]
M/0`)+#P`@D$)`/WK```_+-#_@D!@``'H(`!!ZR@`8>LX`*'K0`#!ZZ8#"'Q0
M`"$X>/OC?^#_@>OX_^'K(`"`3E#H>W\!`-X[=!Y[?Q3R_W\``'J3P/__2P``
MX#O0__]+*`!AZP``X#O$__]+``#`.T3__TL@`$'K*`!AZT``P>NL__]+````
M``````&`!@```@!,/!!70CCP_\'[T?XA^'D;?GSPCRWI^``A^0``(#D0`()!
M```^B0``"2PD`()`^`!!Z?"/+>EY2DI]```@.;@!@D`P`2$X\/_!ZR``@$ZF
M`@A\*`'A^T`!`?C5\O]+&`!!Z'D;?WQX`8)!&`&A^P`!0?O^_T(_"`%A^TCO
M6CMH`&$[>/OC?PGV_TL8`$'H```C+.P`@D$3`".)$P"C.]+_*3D```DL&`""
M0`$`/8D```DLT/^"00```&```$)@$P`CB=+_*3D```DL]`""07CSPW\0`8'[
MF?3_2Q@`0>AX&WQ\>.NC?XGT_TL8`$'H%!I\?`(`8SBT!V-\]?C_2Q@`0>AX
MZZA_>//'?WC31G___Z`X`0"`.'@;?7R5^/]+&`!!Z'C;9']XZZ-_)?+_2Q@`
M0>C__P,L>.NC?Q0`@D&``"&!)@0I50!`"2RD`()!X?C_2Q@`0>AXZZ-_5?/_
M2Q@`0>AX^^-_$`&!ZR7U_TL8`$'H```C+"#_@D```$)@>/OC?VWT_TL8`$'H
M>//#?X'W_TL8`$'H0`$!Z``!0>L(`6'K&`&AZR@!X>NF`PA\@/[_2P```&``
M``!@``!"8`$`/8G2_RDY```)+`3_@D`"`#V)```)+*S^@D'T_O]+0`$!Z"@!
MX>NF`PA\1/[_2QG^_TMD__]+I@((?``!0?L(`6'[$`&!^Q@!H?LH`>'[0`$!
M^-WT_TL8`$'H``````````&`!@``````8```0F`"`$P\X%1".*8""'SX_^'[
M>!M_?!```?@Q_R'X*`"!./"/+>FX`"'Y```@.77R_TL8`$'H```#+$@`@D!`
M`"&!)@0I50!`"2@0`()!__\J;0"@"BPP`()`>/OC?P(`@#A!]?]+&`!!Z#0`
M8WQ^V6-4%```2````&````!@``!"8```8#BX`$'I\(\MZ7E*2GT``"`YM`=C
M?!@`@D#0`"$X$``!Z/C_X>NF`PA\(`"`3A'T_TL8`$'H``````````&``0``
M````8````&```$)@`@!,/!!40CBF`@A\Z/^A^_#_P?O_#Z`X^/_A^W@;?WS^
M_V(\>".>?%#O8S@0``'XL>\A^"@`H3OPCRWI*!`A^0``(#EXZZ1_"?'_2Q@`
M0>@```,L@`"!0#`0@?O__R,YM`<\?3`07#D4"DI]^.]*B0``"BR\`()````)
M+%0`@D%XXX5_+P"`.'CKHW_E[_]+&`!!Z```(RPX`()!````8#B`(ND``&F`
M2?7_2Q@`0>AXXX9_>.NE?WC[Y'_5\/]+&`!!Z#`0@>LP``!(``!"8#`0@>L`
M``!@.(`BZ0``:8`1]?]+&`!!Z'CSQ7]X^^1_8?7_2Q@`0>@H$$'I\(\MZ7E*
M2GT``"`Y,`""0%`0(3@0``'HZ/^AZ_#_P>OX_^'KI@,(?"``@$X```!@``!"
M8+0'?'Q,__]+,!"!^[7R_TL8`$'H``````````&`!````@!,/,!20CBF`@A\
MX/^!^^C_H?OP_\'[^/_A^W@;?WS0_T'[V/]A^Q```?A1_R'X\(\MZ6@`(?D`
M`"`Y```DB3T`*6DT`"E]?MDI511*Q']X\\-_S?#_2Q@`0>AD`($X>!M\?'C[
MXW\!^O]+>1M]?&`!@D&M\/]+&`!!Z$`8/'P0`8%`9@!AZP```&`P@$+K)!][
M>P``/XEX^^I_```)+!P`@D`4`@!(````8```0F`!`"J-```)+`P`@D$]``DL
M\/^"0%!07WVT!TI]`@!\.```NNL44F-\R?3_2Q@`0>@``",L*ME]?&P`@D$`
M`#^)``!:Z?\`)W$JV`I]```HF2``@D"\``!(````8```0F`!`#^-_P`G<0$`
M*IFD`()!/0`'+'A#"GT!``@YY/^"0#T`(#G__]X[>%-(?0``*ID!`#Z-/@8J
M50$`*)T```HL\/^"0&@`0>GPCRWI>4I*?0``(#EH`8)`L``A.!```>C0_T'K
MV/]AZ^#_@>OH_Z'K\/_!Z_C_X>NF`PA\(`"`3O__WCO__[T[````8```0F`!
M`%Z-/@9(50$`79T```@L\/^"0*#__TL```!@``!"8'A#"GUL__]+````8```
M0F!P``'[>``A^P```&`P@$+K```:ZP``..D``"DLU`""07C#"7\``*`[````
M8```0F`)`$GI>.ND?P$`O3L``"HL\/^"0`,`A#BT!X1\)!^$>````&"(@2*!
M```)+&0`@D`!`"`Y````8'@C@WR(@2*18?/_2Q@`0>AY&WE\D`""0;0'NW]X
MPP1_)!][>WC;97^A[O]+&`!!Z```.OL!`#TY``!`.60`H9.T!RE])!\I>2I)
M67UP``'K>``AZPC^_TMXPP-_#>[_2Q@`0>@``",L``!Z^'@;>7PT`()!M`>[
M?R0?>WNX__]+``!`.1#^_TL0`(`X``"@.UC__TMP``'[>``A^\WO_TL8`$'H
M<``!ZW@`(>MP_O]+``````````&`"```````8````&```$)@`@!,/,!/0CBF
M`@A\^/_A^P```&`X@.+K$``!^-'_(?@``'^`??'_2Q@`0>@``'^`<?'_2Q@`
M0>@```!@0("BZ/[_PCS^_X(\J"_&.&#OA#BQ\/]+&`!!Z```?X!%\?]+&`!!
MZ/[_XCS^_Z(\H/+G./[_@CP````Y>#OF?&#-I3B`[X0X_?#_2Q@`0>@P`"$X
M$``!Z/C_X>NF`PA\(`"`3@`````````!@`$`````0F`"`$P\$$]".*8""'P`
M``!@.(`BZ1```?CA_R'X``!I@-'P_TL8`$'H````8$"`HNC^_\(\_O^"/*@O
MQCA@[X0X$?#_2Q@`0>@@`"$X$``!Z*8#"'P@`(!.``````````&`````````
M8````&```$)@`@!,/*!.0CBF`@A\Z/^A^_#_P?L``,`[^/_A^Q```?AAWR'X
M\(\MZ7@@(?D``"`Y,>W_2Q@`0>AH`.$[_O\"/?[_PCQX&V=\F.\(.:#OQC@!
M$*`X`0"`.'C[XW]P$*$[X?#_2Q@`0>AX^^-_>.ND?P`0H#AMZ_]+&`!!Z```
M`RP\`(!!>!M_?`$`8SBT!V-\\?#_2Q@`0>AY&WY\(`""0;0'_W]XZZ1_>/OE
M?_7J_TL8`$'H```@.:[Y/GUX($'I\(\MZ7E*2GT``"`Y)`""0*`@(3AX\\-_
M$``!Z.C_H>OP_\'K^/_AZZ8#"'P@`(!.D>W_2Q@`0>@``````````8`#````
M``!@````8```0F`"`$P\D$U"./#^_TL```````````````````!@``!"8`(`
M3#QP34(XI@((?,C_(?OH_Z'[>!M]?"8`8'WP_\'[^/_A^_[_8CQX(Y]\N.]C
M.!```?@`$0`X"`!AD8'N(?C.`>%_:``A.WC+)'_PCRWI^!`A^0``(#G!]/]+
M+P"`.'@;?GQXZZ-_*>S_2Q@`0>@``",L;`""0?[_8CQXZZ1_R.]C.#7Z_TMX
MZZ-_^!!!Z?"/+>EY2DI]```@.80#@D"`_P`X@!$A.,X`X7\0``'H"`!A@<C_
M(>OH_Z'K\/_!Z_C_X>NF`PA\(`%Q?2"!<'T@`(!.````8````&```$)@>.NC
M?U`10?M8$6'[_O]B/^'J_TL8`$'HV.][.W@;>GQX^^-_;>__2Q@`0>AXVV1_
MP>[_2Q@`0>AY&W]\^`*"02`%R7LH$:'Z,!'!^O[_HCZ,`^`3.!'A^D`1`?L`
M`,`Z_O_B/O[_`C_`#ZDM&!%A^B`1@?H``#XN8!&!^P$`6CL`@-9BL.^U.N#O
M]SKH[Q@[^`"!.P``8#I``)XZ``!"8```/XD```DL:`&"060`DD&0`8Q`(`7I
M>\`/*2R$`8!`F?8`?)G^('P``$`Y!@@@$`;X`!!7#0#P!OP@$.0!F$$,!0`0
M;`(`$&<`"'S__R@Y>$`I??0#*7T42BI]KDA>?:Y(?WQ04&-\```#++P`@D%X
M^^-_W>G_2Q@`0>C__T,Y>!MF?+0'27T42O]\KD@_?2\`"2P\`()`&```2```
M`&````!@````8````&```$)@``!GFGA31GW__THYM`=(?11"_WRN0#]]+P`)
M+.3_@D$4,MI\_P\&+&P`@4%X^^=_>.NI?WB[Z'YXPP9_`!"@.`$`@#AXXX-_
MF>W_2Q@`0>AXRR1_>..#?RGG_TL8`$'H```#+!0`@D"``"&!)@0I50"P"7R<
M`()!>-MD?P``8#@A[?]+&`!!Z```(RQX&W]\P/Z"0!@18>H@$8'J*!&AZC`1
MP>HX$>'J0!$!ZU`10>M8$6'K8!&!ZY#]_TL``$)@%`"200``/HG2_RDY```)
M+!``@D%XJ[]^`0#`.$3__TL!`#Z)```)+)#_@D'H__]+>/OD?WCSPW^)ZO]+
M&`!!Z+C^_TL```!@````8```0F`!`(`X>..#?^GJ_TL8`$'H```#+%3_@D#^
M_V(\>..$?\CO8SA5]_]+>..#?P7M_TL8`$'H&!%AZB`1@>HH$:'J,!'!ZC@1
MX>I`$0'K4!%!ZU@18>M@$8'K]/S_2P``0F`0`$`YF58^?)E6OWT&^`$0!F@A
M$%<-`/`&_"`0!/Z80"``0#F95CY\F5:_?0;X`1`&:"$05PT`\`;\(!#D_9A`
M,`!`.9E6/GR95K]]!O@!$`9H(1!7#0#P!OP@$,3]F$!``)\X>*.#?JGI_TL8
M`$'HV/W_2U`10>M8$6'K7/S_2Q@18?H@$8'Z*!&A^C`1P?HX$>'Z0!$!^U`1
M0?M8$6'[8!&!^PWI_TL8`$'H``````````.`#0``````8```0F```$.)>!MI
M?```"BP@`()-+P`*+`$`*3D(`()`>$LC?0``28D```HLZ/^"0"``@$X`````
M`````````````$)@`@!,/-!(0CBF`@A\^/_A^WD;?WP0``'XT?\A^/0!@D$`
M`#^)```)+.@!@D$%Y_]+&`!!Z/__(SD42C]]0$@_?!P`@$'P`0!(````8```
M0F#__RDY0$@_?.@!@D$``$F)+P"*+^S_GD',`8!`^/CJ?Q1227T#`$AQ.`""
M0?__Z8PO``<L?`""00$`*"PD`()!`@`H+!``@D'__PF-+P`(+&``@D'__PF-
M+P`(+%0`@D&"\$IY`0!*.:8#27W__RDY>$LJ?7P!0$(```F)+P`(+#``@D'_
M_PF-+P`(+"0`@D'^_PJ)_O\J.2\`""P4`()!_?\J.?W_2HDO``HLP/^"0/CX
MZG\44DE]`P!(<40`@D'__RDY0$@_?*@`@$```.F(+P`'+)P`@D`!`"@L)`""
M00(`*"P0`()!__\)C2\`""R``()`__\)C2\`""QT`()`__\).8+P2GE`0#]\
M`0!*.:@`@4'__S\LH`""00$`*BS__RDY>$LH??__2CE$`()!``#IB"\`!RPX
M`()`___IC"\`!RPL`()`_O_HB/[_*#DO``<L'`""0/W_*#G]_PB)+P`(++C_
M@D$```!@``!"8%!(/WT``&`X`@!).0`0*B@D`(%!````8`$`J3B0@4(Y>/OD
M?WA30WT`$,`X9>G_2Q@`0>@P`"$X$``!Z/C_X>NF`PA\(`"`3@$`0#E@__]+
M_O]B/+#O8SBYZ?]+&`!!Z#``(3@0``'H^/_AZZ8#"'P@`(!.S/Z"0````&``
M`$)@```_B2\`"2S(_X)!_O]B/.#O8SA]Z?]+&`!!Z#``(3@0``'H^/_AZZ8#
M"'P@`(!.``````````&``0````!"8`(`3#Q01D(XI@((?/#_P?OX_^'[_O_"
M/]#_0?O8_V'[\._>.^#_@?OH_Z'[$``!^&'_(?CPCRWI:``A^0``(#ED`.$[
M>/OD?WCSPW^M[?]+```C+%``@D%F`$'I````8#"`(ND```GI)!]*>112*'T(
M`.GH```G+"I1Z'S(_X)!$`!)Z0``*BP)`$GY]/^"0'C[Y']X\\-_8>W_2P``
M(RRX_X)`_O_"/P#PWCMX^^1_>//#?T7M_TL``",L6`""068`0>D```!@,(`B
MZ0``">DD'TIY%%(H?0@`Z>@``"<L*E'H?,C_@D$```!@``!"8!``2>D``"HL
M"0!)^?3_@D!X^^1_>//#?_'L_TL``",LL/^"0/[_PC\(\-X[>/OD?WCSPW_5
M[/]+```C+%@`@D%F`$'I````8#"`(ND```GI)!]*>112*'T(`.GH```G+"I1
MZ'S(_X)!````8```0F`0`$GI```J+`D`2?GT_X)`>/OD?WCSPW^![/]+```C
M++#_@D#^_\(_&/#>.WC[Y']X\\-_9>S_2P``(RQ8`()!9@!!Z0```&`P@"+I
M```)Z20?2GD44BA]"`#IZ```)RPJ4>A\R/^"00```&```$)@$`!)Z0``*BP)
M`$GY]/^"0'C[Y']X\\-_$>S_2P``(RRP_X)`_O_"/R#PWCMX^^1_>//#?_7K
M_TL``",L6`""068`0>D```!@,(`BZ0``">DD'TIY%%(H?0@`Z>@``"<L*E'H
M?,C_@D$```!@``!"8!``2>D``"HL"0!)^?3_@D!X^^1_>//#?Z'K_TL``",L
ML/^"0/[_HC\P\+T[>/OD?WCKHW^%Z_]+```C+%@`@D%F`$'I````8#"`(ND`
M``GI)!]*>112*'T(`.GH```G+"I1Z'S(_X)!````8```0F`0`$GI```J+`D`
M2?GT_X)`>/OD?WCKHW\QZ_]+```C++#_@D#^_Z(_N.^].WC[Y']XZZ-_%>O_
M2P``(RQ8`()!9@!!Z0```&`P@"+I```)Z20?2GD44BA]"`#IZ```)RPJ4>A\
MR/^"00```&```$)@$`!)Z0``*BP)`$GY]/^"0'C[Y']XZZ-_P>K_2P``(RRP
M_X)`_O^"/T#PG#MX^^1_>..#?Z7J_TL``",L6`""068`0>D```!@,(`BZ0``
M">DD'TIY%%(H?0@`Z>@``"<L*E'H?,C_@D$```!@``!"8!``2>D``"HL"0!)
M^?3_@D!X^^1_>..#?U'J_TL``",LL/^"0/[_8C]0\'L[>/OD?WC;8W\UZO]+
M```C+%@`@D%F`$'I````8#"`(ND```GI)!]*>112*'T(`.GH```G+"I1Z'S(
M_X)!````8```0F`0`$GI```J+`D`2?GT_X)`>/OD?WC;8W_AZ?]+```C++#_
M@D#^_T(_8/!:.WC[Y']XTT-_Q>G_2P``(RQ8`()!9@!!Z0```&`P@"+I```)
MZ20?2GD44BA]"`#IZ```)RPJ4>A\R/^"00```&```$)@$`!)Z0``*BP)`$GY
M]/^"0'C[Y']XTT-_<>G_2P``(RRP_X)`_O]"/\CO6CMX^^1_>--#?U7I_TL`
M`",L6`""068`0>D```!@,(`BZ0``">DD'TIY%%(H?0@`Z>@``"<L*E'H?,C_
M@D$```!@``!"8!``2>D``"HL"0!)^?3_@D!X^^1_>--#?P'I_TL``",LL/^"
M0/[_8CQX^^1_</!C..GH_TMY&V1\#`""07C;8W]Y[O]+_O]B/'C[Y'^(\&,X
MR>C_2WD;9'P0`()!_O]B/*#P8SA5[O]+_O]B/'C[Y'^P\&,XI>C_2WD;9'Q8
M`()!>.NC?S7N_TO^_X(\>//#?]CPA#@E[O]+:`!!Z?"/+>EY2DI]```@.5``
M@D"@`"$X$``!Z-#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#"'P@`(!._O]B
M/'C[Y'_`\&,X.>C_2WD;9'R@_X)!>..#?\GM_TN4__]+6>#_2Q@`0>@`````
M`````8`&`````$)@`@!,/&!`0C@```!@$($B@9'_(?C__PDL\(]-Z6@`0?D`
M`$`Y+`""06@``>GPCTWI>5((?0``0#FT!R-]:`""0'``(3@@`(!.````8```
M0F"F`@A\_O]B/&0`@3A`\&,X@``!^*7G_TL``"`Y```C+"``@D$``$.)```*
M+!0`@D$P`$II-`!*?7[92E4!`$EI@``!Z````&`0@2*1I@,(?(C__TNF`@A\
M@``!^)7?_TL8`$'H``````````&``````@!,/*`_0CBF`@A\$``!^.'_(?BM
MW?]+&`!!Z`7<_TL8`$'H```C+`@`@D$``&/H(``A.!```>BF`PA\(`"`3@``
M```````!@```````0F`"`$P\4#]".*8""'SH_Z'[\/_!^_[_HC_X_^'[X/"]
M.W@;?GQXZZ-_$``!^''_(?AD`($X\(\MZ6@`(?D``"`YN>;_2WCSQ']Y&W]\
M$`""00``/XD```DL2`""0'CKHW\Y[/]+:`!!Z?"/+>EY2DI]```@.:P`@D"0
M`"$X$``!Z.C_H>OP_\'K^/_AZZ8#"'P@`(!.````8````&```$)@L=W_2Q@`
M0>@``",LN/^"0'CSPW]P`('[^=S_2Q@`0>AX&WQ\>/OC?^G<_TL8`$'H%!I\
M?`(`8SA9X?]+&`!!Z/[_`CW^_\(\>/OI?WCSQW_8[P@YZ._&./__H#@!`(`X
M>!M_?.W@_TL8`$'H>/OD?WCKHW^%Z_]+<`"!ZTC__TMP`('[#=[_2Q@`0>@`
M`````````8`$``````!@``!"8`(`3#P0/D(XI@((?-#_0?O8_V'[````8.C_
MH?OX_^'[$($B.0@`@#BX_^'ZP/\!^R``P#@P`.`XR/\A^^#_@?M````Y4`!`
M.?#_P?L```!@<(&BZ```X#N8)BE]>!M[?!```?C__P`\J('_8Y@V27T```!@
M*(%BZ0!^`&"8/FE]F$:)??__P#R85@E\___@//__`#UJ`2%\__]`/?__(#W^
M_T(_4'_&8(!_YV"0?PAAH']*86A_*6&P@:$[%`K_?_"/;>@``'_X``!@.+CO
M6CMX?[WX``"@.&!_??FP@:5@%`JE?,!^G3AXTT-_F#<E?9@_17V81V5]F%>%
M?9A/!7RYY/]+>1M_?!``@D$``#^)```)+`P&@D`9V_]+&`!!Z''9_TL8`$'H
M```C+`0%@D$``,/K```^+/@$@D%X\\-_,=O_2Q@`0>BD#V-X`0!C.*'?_TL8
M`$'H``#^B'@;?'P```<L2`""0?[_(C]XXY]_^/`Y.P```&````!@``!"8+0'
MYWQX^^-_>,LF?___H#@!`(`X`@#_.QG?_TL8`$'H`0#^C```!RS8_X)`_O]B
M/(!_W3N@\&,XP'X].Q```$@)`'[H```C+(@!@D%XRR1_Z>/_2WD;?WSH_X)!
M```_B0``"2S<_X)!4>?_2P```RS0_X)!>/OC?QG?_TL8`$'H>1M_?$P!@D$`
M``!@``!"8'C[XW_^_R(_6=K_2Q@`0>C@[SD[>!M^?'CC@W]%VO]+&`!!Z!0:
MWG\$!-X[M`?>?WCSPW^MWO]+&`!!Z/[_(CW^_\(\>..*?WC[YW]XRRA_`/$I
M.0CQQCC__Z`X`0"`.'@;?'P]WO]+&`!!Z'CC@W_``8`X[=K_2Q@`0>C__P,L
M&`""0#W;_TL8`$'H```#@1$`""P\!()`P'X=.WCC@W]XPP1_'=G_2Q@`0>@`
M``,L>!M_?#P!@D$```!@2(`BZ0``V^C^_Z(\>..'?UCQI3@!`(`X``#`.P``
M:>BEV?]+&`!!Z```(#FH@2EA%`HI?0``2>GPCRWI>4I*?0``(#E("()````A
MZ'CSPW\0``'HN/_AZL#_`>O(_R'KT/]!Z]C_8>O@_X'KZ/^AZ_#_P>OX_^'K
MI@,(?"``@$X``$)@``#`.P```&````!@``!"8+0'R7\``$`Y)!\I>;"!2F$4
M2DI]%`HJ??__Z3]0?__K```_+&P`@D$``#^)```)+&``@D%X^^-_`0#>.YWE
M_TL```,LO/^"07C[XW]EW?]+&`!!Z'D;?WQ8_H)`M`?)?P``0#DD'REYL(%*
M811*2GT4"BI]___I/U!__^L``#\LJ/^"0````&````!@``!"8```X#L<_O]+
M````8```0F#8?CV!)@0I50!`"2R\_H)`W'[]@AW8_TL8`$'H`!@7?*C^@D#8
M?CV!_@4I5<`!"2R8_H)`>//#?[G<_TL8`$'H>,,$?W@;?GS^_V(\L/%C.&GA
M_TMY&V1\Z`*"00``>^A)[/]+>1MW?-@"@D%XN^-^`=C_2Q@`0>@#``,L>!MX
M?*``@4"T!V-\_O^"//S_8SBX\80X%!IW?"`%:7C`#RDL^`2`0"`%B7C`#RDL
M[`2`0)D>`'R9)J!]C`,@$```0#D&:*`1!@@`$%=M`/`&#*`18`2800P%`!!L
M`@`09P`(?/__*#EX0"E]]`,I?11**GVN2$-]KDAD?%!08WP```,L(`""0`0`
M&"R<!()!^_\X.;0'*7VN2#=]+P`)+(@$@D$```!@$($B@?__"2S$`X)!```)
M+/[_`C]`\!@[)`*"0?[_@CQXPP-_V/"$./[_HC\)YO]+H/*]._[_8C_H\7L[
M<=?_2Q@`0>C^_\(\>.NJ?WC+*']XXX=_>!MI?-CQQCC__Z`X`0"`.'CSPW\E
MV_]+&`!!Z%@``$@```!@``!"8#'8_TL8`$'H```C@1$`"2Q4`()`'=?_2Q@`
M0>A@`*'[`0#_.WC+*'^T!^I_>..'?W@;:7QXVV9___^@.`$`@#AX\\-_S=K_
M2Q@`0>C``8`X>//#?WW7_TL8`$'H__\#+*#_@D%XXX-_J=7_2Q@`0>AXTT-_
M>//$?T'E_TMX\\-_J?C_2]#\_TL```!@``!"8```X#O`?IT[````8```0F"T
M!^E_``!`.20?*7FP@4IA%$I*?10**GW__VD\:']CZ```(RQ<`()!>..$?P$`
M_SM)W_]+>1MI?,C_@D$``"F)```)++S_@D&)VO]+&`!!Z'D;?GRH^H)`M`?I
M?P``0#DD'REYL(%*811*2GT4"BI]__]I/&A_8^@``",LK/^"0`T`8#C^_\(_
M*=K_2Q@`0>CP\-X[4P#@.'@;?'R,^O]+````8$B`(ND``-OH_O^B/+0'"'UX
MXX=_&/&E.`$`@#@``,`[``!IZ(G5_TL8`$'HY/O_2P```&````!@``!"8*GW
M_TMX^^-_Z=G_2Q@`0>AX&WY\P/O_2P```&```$)@``#[ZBC]_TL``"`Y````
M8!"!(I$```!@````8```0F!XN^-^``"`.*G4_TL8`$'H_O\"/T#P&#L```,L
M>!M[?'@;=WR\_8)!`@"@..[_@#@AV/]+&`!!Z/A__3L&`*`X>/OD?WC;8W^I
MU?]+&`!!Z/A_/8D```DL$`""0/E_/8E#``DLD`*"07C;8W\``*`X``"`.+0'
M^W[9U_]+&`!!Z/__X#KX?_T[(`3W5ET>`$@```!@>!MX?!P``$@``$)@M`=E
M?'C[Y']XPP-_W1X`2````&!XN^5^>/OD?WC;8W\QU?]+&`!!Z````RS4_X%!
M>-MC?\A__3O9U?]+&`!!Z'C#!'^P?WTX_O\"/Z]_?3NI(`!(````8,-__3KX
M\!@[`0#[C'C[XW]XPP9___^@.`$`@#@"`/\[.=C_2Q@`0>A`V#=\W/^"0```
MH#C^_T(]_O_"/'C+*'_P?[V8R'\].:#R2CEXXX=_R/'&./__H#@!`(`X>//#
M?_G7_TL8`$'H>..#?^W2_TL8`$'H>--#?WCSQ'^%XO]+>//#?^WU_TL4^O]+
M````8````&```$)@_O\"/\!^G3A`\!@[>,,#?[G<_TL``",L0`&"00``(XD`
M``DL./Z"03``"2PL_H)!`0`@.0```&`0@2*1%/S_2Q``0#F95J-]F5:$?08(
M#1`&8*T15VT`\`8,H!&(^YA`(`!`.9E6HWV95H1]!@@-$`9@K1%7;0#P!@R@
M$6C[F$`P`$`YF5:C?9E6A'T&"`T0!F"M$5=M`/`&#"`02/N80$``A#A``&,X
MN=3_2Q@`0>A<^_]+"`![ZP``.RQT^X)!>-MC?[W2_TL8`$'H`P`C*&#[@4#\
M_V,X_O^"/!0:>WS`\80X(`5I>,`/*2QL`8!`(`6)>,`/*2Q@`8!`F1X`?)DF
MH'V,`R`0```@.09HH!$&"``05VT`\`8,H!'4`)A!#`4`$&P"`!!G``A\__](
M.7A`2GWT`TI]%%(I?:Y(0WVN2"1]4%`I?0``"2SD^H)`>-MW?]SZ_TL```!@
M$(%BD!#]_TOZ?SV)00`)+&S]@D#[?SV)0P`)+&#]@D#\?SV)2``)+%3]@D#]
M?SV)10`)+$C]@D`"`*`XQO^`.'C;8W\AU?]+&`!!Z'C[Y']XVV-_*0"@.*W2
M_TL8`$'H_O]"/?[_PCQX^^E_>,LH?Z#R2CEXXX=_R/'&./__H#@!`(`X>//#
M?]W5_TL8`$'H*/O_2Q``(#F93J-]F4Z$?08(#1`&8*T15VT`\`8,H!$4_YA`
M(``@.9E.HWV93H1]!@@-$`9@K1%7;0#P!@R@$?3^F$`P`"`YF4ZC?9E.A'T&
M"`T0!F"M$5=M`/`&#"`0U/Z80$``A#A``&,X"=/_2Q@`0>AX&VE\Y/[_2YG2
M_TL8`$'H``````````&`"0````!"8`(`3#R@,D(XI@((?.C_H?OP_\'[^/_A
M^P```&`X@.+K$``!^''_(?@``'^`\(\MZ6@`(?D``"`Y9`"A.T74_TL8`$'H
M>!M^?```?X`UU/]+&`!!Z+``7HEXZZ1_>!MI?/[_8CP@\&,XL0!)F=W9_TL`
M`",L$`""00``(XDQ``DLP`&"0=7K_TL``'^`]=/_2Q@`0>C^_X(\`P#`.`$`
MH#@`\H0XG<[_2Q@`0>AY&WY\/`""00``?X#)T_]+&`!!Z!``/NG^_Z(\"/*E
M.```B>@1U/]+&`!!Z!``/ND``"GI#``I@4``*778`8)```!_@)'3_TL8`$'H
M_O^"/`,`P#@!`*`X$/*$.#G._TL8`$'H>1M^?$@`@D'^_V(\>.ND?W``@?O(
M[V,X(=G_2^[^`'QY&WQ\Y@`#?%@!@D%%T_]+&`!!Z!``/NEXXX5_``")Z)'3
M_TL8`$'H<`"!ZP``?X`AT_]+&`!!Z'@;?GP``'^`$=/_2Q@`0>C^_X(\`0"@
M.!CRA#A]SO]+&`!!Z/[_HCPP\J4X>!MD?'CSPW]%T_]+&`!!Z```?X#9TO]+
M&`!!Z```0#EXZZ1_>!MI?/[_8CRX[V,XL0!)F8'8_TL```!@```C+)B18OAX
M&W]\=`""0<`!@#AX^^-_&=#_2Q@`0>@1``,L$`""00$`(SD!``DHX`"!06@`
M0>GPCRWI>4I*?0``(#GT`()`D``A.!```>CH_Z'K\/_!Z_C_X>NF`PA\(`"`
M3@```&````!@``!"8`$`(XD```DL0/Z"03C^_TL```!@D)%BZ$'R_TL```!@
M```C+)B18OAX&W]\=/^"0/[_8CQP`('[./)C.(70_TL8`$'H````8````&``
M`$)@\='_2Q@`0>@0`%[I````8)"1(ND``&KH``")Z.W;_TMP`('KJ/[_2P``
M`&```$)@``!_@+W1_TL8`$'H$``^Z0``B>CMS/]+&`!!Z!#^_TMP`('[````
M8)"1(NEX&V9\_O]B/'C[Y7]@\F,X``")Z`'0_TL8`$'H<`"!^W7/_TL8`$'H
M``````````&`!````@!,/(`O0CBF`@A\\/_!^_C_X?MX&WY\$``!^('_(?CP
MCRWI:``A^0``(#F-YO]+```CB7@;?WP```DL(`""02\`"2P!`&,X"`""0'@;
M?WP``".)```)+.C_@D````!@$($B@?__"2RH`()!```)+'``@D$``#XL:`""
M00``/HD```DL7`""02`%Z7O^_X(\_`\I+`#QA#@``8!`+/Q`?2PD`'T``"`Y
M`@!*>0(`"'GX0T=]^$M)?3D[*7T8`()!=``I?0@`*3DP3DIY,$X(>5!0*'T`
M``DLD`""00``0F!H`$'I\(\MZ7E*2GT``"`YP`""0(``(3@0``'H\/_!Z_C_
MX>NF`PA\(`"`3@``0F#^_V(\9`"!.$#P8S@-UO]+```C+"@`@D$``".)```)
M+"P`@D$P``DL(`""00$`(#D```!@$($BD2S__TL```!@$(%BD(S__TL``"`Y
M````8!"!(I%\__]+:`!!Z?"/+>EY2DI]```@.3@`@D"``"$X>//#?Q```>CP
M_\'K^/_AZZ8#"'SDUO]+>/OC?P0`H#B!S?]+&`!!Z'@;:7PH__]+L<W_2Q@`
M0>@``````````8`"``````!@````8````&`"`$P\L"U".,#_`?O(_R'[.`#C
M.-#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q'](?CPCRWIJ`(A^0``(#D(`"`Y
MI@,I?2@``3D```!@``!"8```1^DL/,!\$``(.0@`YS@@PDEY($9%>2X$*54B
M`$IY>"LI?2C`17EX*RE]'D)*57A3*7T@`,IX^/\H^?#_2/G`_P!"0``@.2``
M`3FF`RE]>$,*?0D`Z.AP`"KI2`#*Z!@`2NEX,BE]>%(I?7@Z*7VD#RIYP@\I
M>7A+27T@`"EY@``H^<S_`$(```/H*``!Z1``P^@8`*/H&X]`/6+*(#T(`(/H
M(`!CZ3``@>DX`,'KW+Q*8=;!*6$@`$IY(``I><(N''BD+A]X@EKH/'CC_W^9
M>><X>"K<?(+PG7@46N=\9/"(>"``_WLX()Q_>.L(?7@JG'\4.O]_(``=>13B
M_W]XZL=\XB[[>\@N_'N"6HP]>-N<?X+P&G@X`.=\9/`;>)EYC#EXTWM_%"J,
M?7@RYWP@`/][%&+G?$``@>EXV@A]@EK>/Q3BYWPX^`A]F7G>.^(N_'@4,MY_
MR"[Z>'CJ"'UXXUI_%/((?63P_'M(`,'K@O#_>X):C#UX^YQ_%-((?9EYC#D@
M`.=X>.)_?Q3JC'W(+AIYXBX=>2``>WMXZUI_.#C_?V3P_7B"\.=X>-K_?W@[
MO7\@``AY>.J'?Q1B_W]0`('I@EK>/Q32_W\X0.=\(`":>YEYWCMXTN=\%-K>
M?V3P''F"\`AYR"[[>WA#G'\4\N=\XB[^>WCBJ']X\WM_(`#_>U@`P>N"6HP]
M%-KG?#CX"'UD\/M[F7F,.8+P_WMX^WM_(`"X>V``X>L4THQ]XB[]>,@N^GAX
MP@A]>.M:?X):WC\@`/UX>-J'?R``F7L48@A]N`"!Z3CHYWR9>=X[%-((?13"
MWG]XRN=\R"X:>13RYWSB+AYY>/-:?V3PO'N"\+Y[@EK_/WCSG'\@`!UY:`#!
MZWCB:'\@`'A[..@(?9EY_SL4TN=\%,K_?WC""'W(+OIX%/H(?>(N_WAX^UI_
M9/"[>X+POWN"6MX_>/M[?R``_7AP`.'K>-J'?R``F7LXZ.=\F7G>.Q32"'T4
MPMY_>,KG?,@N&GD4\N=\XBX>>7CS6G]D\+Q[@O"^>X):_S]X\YQ_(``=>7@`
MP>MXXFA_(`!X>SCH"'V9>?\[%-+G?!3*_W]XP@A]R"[Z>!3Z"'WB+O]X>/M:
M?V3PNWN"\+][@EK>/WC[>W\@`/UX@`#AZWC:AW\@`)E[..CG?)EYWCL4T@A]
M%,+>?WC*YWS(+AIY%/+G?.(N'GEX\UI_9/"\>X+POGN"6O\_>/.<?R``'7F(
M`,'K>.)H?R``>'LXZ`A]F7G_.Q32YWP4RO]_>,((?<@N^G@4^@A]XB[_>'C[
M6G]D\+M[@O"_>X):WC]X^WM_(`#]>)``X>MXVH=_(`"9>SCHYWR9>=X[%-((
M?13"WG]XRN=\R"X:>13RYWSB+AYY>/-:?V3PO'N"\+Y[@EK_/WCSG'\@`!UY
MF`#!ZWCB:'\@`'A[..@(?9EY_SL4TN=\%,K_?WC""'W(+OIX%/H(?>(N_WAX
M^UI_9/"[>X+POWN"6MX_>/M[?R``_7B@`.'K>-J'?R``F7LXZ.=\F7G>.Q32
M"'T4PMY_>,KG?,@N&GD4\N=\XBX>>7CS6G]D\+Q[@O"^>X):_S]X\YQ_(``=
M>:@`P>MXXFA_(`!X>SCH"'V9>?\[%-+G?!3*_W]XP@A]R"[Z>!3Z"'WB+O]X
M>/M:?V3PNWN"\+][@EK>/WC[>W\@`/UXL`#AZWC:AW\@`)E[..CG?)EYWCL4
MT@A]%,+>?WC*YWS(+AIY%/+G?.(N'GEX\UI_9/"\>X+POGN"6O\_>/.<?R``
M'7EXXFA_F7G_.R``>WLXZ`A]%-+G?!3*_W]XV@A]R"[Z>!3Z"'WB+O]X>/M:
M?V3POGN"\+][@EJ,/7C[W7\4T@A]P`#!ZR``YWAXZI]_F7F,.2``FGL4VHQ]
MXBX<>3@X_W\H*!MY>.-[?WC2_W]D\/QX@O#G>'@[G'\48O]_R`#AZ!3:GWT@
M``AY>.*_?X):WC\@`+M[.$#_?YEYWCMXVO]_%-+>?^(NG7D4\O]_*"B>>7CK
MWG]D\!UY@O`(>13R_W]X0[U_VF[G/-```>EXZIY_B/":>7ABWG^AZ^<XHO",
M>13:YWQX8UI_XB[[>R@H^7L@`-Y[>-LY?Q0ZWG\@`)M[VF[H/-@``>EXTKQ_
MH>OG.'CZG'\4RMY_%-KG?"``G'OB+ME[%.+G?"@HVWN(\/Q[HO#_>WC+>W]X
M^YQ_VFX(/>``X>L4VH=](`"]>WCB1W^AZP@YXBZ;>7CRYWP4Z@A]*"B=>7C;
MO7\@`.=XB/#;>Z+PWGMX\WM_%#H(?>@`X>@4ZLA_VF[_/WC:B'\@`%I[>&((
M?:'K_SOB+ME[%-+_?R``"'DH*-I[B/"=>:+PC'EX8[U_%$+_?_```>EXRUI_
MVF[G/!32GWT@`)Q[>.I_?Z'KYSAX\O]_%.+G?"@HFGGB+IQY>.-:?R``_WN(
M\-Q[HO#>>WCSG'\4^N=\^`#AZQ32QW_:;@@]>.*G?R``>WMX8N=\H>L(.>(N
MV7L4V@A](`#G>"@HVGN(\)MYHO",>7AC>W\4.@A]``'AZ'C+6G_:;O\_%-*(
M?2``O7MXVHA_H>O_.WCR"'T4ZO]_*"B:>>(NG7EXZUI_(``(>8CPW7NB\-Y[
M>/.]?Q1"_W\(`0'I%-+??]INYSQXZG]_(`"<>WAB_W^AZ^<XXB[9>Q3BYWP@
M`/][*"C:>XCPG'FB\(QY>&.<?Q3ZYWP0`>'K>,M:?]IN"#T4TH=](`![>WCB
MIW^AZP@Y>/+G?!3:"'TH*)IYXBZ;>7C;6G\@`.=XB/#;>Z+PWGMX\WM_%#H(
M?1@!X>@4TLA_VF[_/WC:B'\@`+U[>&((?:'K_SOB+ME[%.K_?R``"'DH*-I[
MB/"=>:+PC'EX8[U_%$+_?R`!`>EXRUI_VF[G/!32GWT@`)Q[>.I_?Z'KYSAX
M\O]_%.+G?"@HFGGB+IQY>.-:?R``_WN(\-Q[HO#>>WCSG'\4^N=\*`'AZQ32
MQW_:;@@]>.*G?R``>WMX8N=\H>L(.>(NV7L4V@A](`#G>"@HVGN(\)MYHO",
M>7AC>W\4.@A],`'AZ'C+6G_:;O\_%-*(?2``O7MXVHA_H>O_.WCR"'T4ZO]_
M*"B:>>(NG7EXZUI_(``(>8CPW7NB\-Y[>/.]?Q1"_W\X`0'I%-+??]INYSQX
MZG]_(`"<>WAB_W^AZ^<XXB[9>Q3BYWP@`/][*"C:>XCPG'FB\(QY>&.<?Q3Z
MYWQ``>'K>,M:?]IN"#T4TH=](`![>WCBIW^AZP@Y>/+G?!3:"'TH*)IYXBZ;
M>7C;6G\@`.=XB/#;>Z+PWGMX\WM_%#H(?4@!X>C:;O\_%-+(?R``O7MXVHA_
MH>O_.WAB"'T4ZO]_B/"=>:+PC'GB+MI[>&.]?R@HV7M8`8'I>-,Y?R``"'D@
M`)I[VF[G/'CJ?'\40O]_4`$!Z7CRG'^AZ^<X%,K_?Q32YWP@`)Q[XB[Y>Q3B
MYWPH*/I[B/#<>Z+PWGMX\YQ_>,M:?Q32QW_:;@@]>.*G?R``>WMX^N=\H>L(
M.>(NV7L4V@A](`#G>"@HVGN(\/M[HO#_>WC[>W\4.@A]8`'AZ'C+6G_:;HP]
M%-+H?WC:B'\@`+U[>/((?:'KC#D@``AY%.J,?<@N_7L40HQ]XB[H>WA#J'^(
M\-U[HO#>>Q1"C'UX\[U_VF[G/&@!P>MXZFA_(`"<>WCZ"'VAZ^<X%.+G?"``
M"'D40N=\B/#H>Z+P_WOB+IQY>/L(?<@NFGEXXUI_>$._?R``G'D@`'M[(``,
M>13RRG\4VMY_..#_?SA@NW\4TN=\<`%!ZWC;_W_(+OEX%/+_?^(N_GAX\SE_
M9/">>X+PG'L@`/MX>./>?Q3*_W]X`8'K>/,(?3A@QW\4TDI_.-@(?2``O7MX
M.PA]%.JZ?^(NYWO(+OI[%.H(?7@[6G]D\&=[@O![>R``_7MXV^=\%-((?7@[
MWW\@`/IX.-#;?Q3BBG\XZ/]_%&*<?WC;_W_(+AMY%.+_?^(N''EXXWQ_9/"[
M>X+PO7L@``AY>.M[?R``WGMXV^Q\@`'AZ!3B_W\X0(Q](`#]>Q0ZZGP4\N=\
M.-!^?WCSC'W(+OY[%#J,?>(NYWMX.]Y_9/`'>8+P"'EX0^=\%/(,?8@!P>L@
M`/QX>#M_?SCH_W_(+AEY%/+*?Q32WG\XX'I_>-/_?Q3R_W_B+AYY>/,Y?V3P
MOGN"\+U[(``(>7CKVG\@`'Y[>-/L?)`!X>@4RO]_.$",?2``_7L4.NI\%/+G
M?#C@7G]X\XQ]R"[^>Q0ZC'WB+N=[>#O>?V3P!WF"\`AY>$/G?!3R#'V8`<'K
M(`#[>'@[7W\XZ/]_R"X9>13RRG\4XMY_.-A<?WCC_W\4\O]_XBX>>7CS.7]D
M\+Y[@O"]>R``"'EXZ]Q_(`!>>WCC['R@`>'H%,K_?SA`C'T@`/U[%#KJ?!3R
MYWPXV)Y_>/.,?<@N_GL4.HQ]XB[G>W@[WG]D\`=Y@O`(>7A#YWP4\@Q]J`'!
MZR``^GAX.Y]_..C_?\@N&7D4\LI_%-K>?SC0FW]XV_]_%/+_?^(N'GEX\SE_
M9/"^>X+PO7L@``AY>.O;?R``GGMXV^Q\L`'AZ!3*_W\X0(Q](`#\>Q0ZZGP4
M\N=\.-!^?WCSC'W(+OY[%#J,?>(NYWMX.]Y_9/`'>8+P"'EX0^=\%/(,?;@!
MP>L@`/UX>#M_?SC@_W_(+AEY%/+*?Q32WG\XZ'I_>-/_?Q3R_W_B+AYY>/,Y
M?V3PGGN"\)Q[(``(>7CCVG\@`'Y[>-/L?,`!X>@4RO]_.$",?2``^WL4.NI\
M%/+G?#CH7G]X\XQ]R"[^>Q0ZC'WB+N=[>#O>?V3P!WF"\`AY>$/G?!3R#'W(
M`<'K(`#\>'@[7W\XV/]_R"X9>13RRG\4ZMY_..!=?WCK_W\4\O]_XBX>>7CS
M.7]D\'Y[@O![>R``"'EXV]U_(`!>>]@!0>MXZ^Q\T`'AZ!3*_W\X0(Q]R"[[
M>Q322G\4.NI\%.):?Q3RYWPXX+Y_>/.,?2``_GL4.HQ]XB[G>W@[>W]D\`=Y
M@O`(>7A#YWP4V@Q]>#N_?R``^W@XV+Q_./#_?WCC_W_(+AEYXBX<>132_W]X
MXSE_9/#:>X+PW'L@`+Y[X`&AZWCC6G\@``AY>-/L?!3*_WSH`>'K%.JJ?SA`
MC'T4\MU_.-A=?WCKC'W(+OUX%/*,?>(N_GAX\[Y_9/`=>8+P"'D@`/QX>$.G
M?Q3ZZG_P`:'K%/(,?2``_GAX.TQ_%-K_?SC@C'TX\%M_>-N,?<@N&7D4^HQ]
MXBX?>7C[.7]D\)][@O"<>R``"'EXX_M_%.JJ?R``7WMXV^=\%/J]?SA`YWPX
M\']_%,J,?0`"(>MX^^=\R"Z?>13JYWSB+IUY>.O_?V3P&GF"\`AY(`"=>7A#
M6G\4^@=]^`'AZ"``7'MXTVQ_..B,?2@H&'D4.NI_..!G?Q3R_W]D\+Y[@O"]
M>W@[C'UXZ]Y_XBX'>0@"H>L@``AY%/J,?7@[&'\@`'][$`)AZWCS1W\4RDI]
M.$#G?!3Z2GTXX-]_%,*,?7C[YWQD\!IYXBZ?>1121WV"\`AY*"B'>7A#6G]X
M^^=\&`+AZQ0Z2GT4ZJE_>-+'?Q3BO7^B\(AY>&+G?(CPG'D@`.=X>$.<?^(N
M67EXXDA_%.KG?"@H77D4VFE_>,N]?WA2"'T@`-Y[%.KG?"`"H>L4\MM_(``(
M>>(N^7BB\$QY%/((?8CP6WDH*/YX>&-[?R@"@>EXR\I_(`!:>Q12"'UXVHI_
M%/KI?W@Z2GT4TO]_(`!*>8CP_GBB\.=X>#O>?^(N&GDP`N'H%%+_?R@H"GEX
MTTI]>/)Z?Q12_W\@`)Q[%.I)?7A"77\4XDI](`"]>^(N^GL4ZDI]B/`<>2@H
M_7NB\`AY>-.]?WA#G'\4ZDI].`(!Z7CBW7\@`'M[%&*)?7CZO7\4VHQ](`"]
M>Q3JC'V(\/U[HO#_>^(N6WEX^[U_*"A:>4`"X>MXVUI_(`#;>WCJGG\4.NE\
M>%+>?Q32C'T4VN=\(`#>>^(NFGD4\N=\B/!;>2@HGGFB\$IY>-/>?WA3>W\4
M\N=\2`)!Z7C:OG\@`)Q[%$()?7ABWG\4X@A](`#>>Q3R"'V(\)YYHO",>>(N
M_'AX8]Y_*"CZ>%`"@>EXXUI_(`"\>WCR?7\4^NE_>#J]?Q32"'T4XO]_(`"]
M>^(N&GD4ZO]_B/#\>"@H'7FB\.=X>-.]?W@[G'\4ZO]_6`+AZ'CBW7\@`'M[
M%%))?7A"O7\4VDI](`"]>Q3J2GV(\!UYHO`(>>(N^WMX0[U_*"CZ>V`"`>EX
MVUI_(`#;>WCJGG\48HE]>/K>?Q322GT4VHQ](`#>>^(N6GD4\HQ]B/#[>R@H
M7GFB\/][>-/>?WC[>W\4\HQ]:`+AZWC:OG\@`)Q[%#KI?'A2WG\4XN=\(`#>
M>Q3RYWR(\%YYHO!*>>(NG'EX4]Y_*"B:>7`"0>EXXUI_(`"\>WCR?7\40@E]
M>&*]?Q32YWP4X@A](`"]>^(N^G@4Z@A]B/"<>2@H_7BB\(QY>-.]?WACG'\4
MZ@A]>`*!Z7CBW7\@`'M[%/KI?W@ZO7\4VO]_(`"]>Q3J_W^(\/UXHO#G>.(N
M&WEX.[U_*"@:>8`"X>AXVUI_(`#;>WCJGG\44DE]>$+>?Q3:2GT@`-Y[%-+_
M?Q3R2GV(\!YYHO`(>>(N^WMX0]Y_*"CZ>X@"`>EXVUI_(`";>WCRO'\48HE]
M>/J<?Q3:C'T@`)Q[%-)*?13BC'V(\/Q[HO#_>^(N6WEX^YQ_*"A:>9`"X>MX
MVUI_(`"[>WCBW7\4.NE\>%*]?Q3:YWP@`+U[%-*,?13JYWR(\%UYHO!*>>(N
MFWEX4[U_*"B:>9@"0>EXVUI_(`#;>WCJGG\40@E]>&+>?Q3:"'T@`-Y[%-+G
M?!3R"'V(\)YYHO",>2``FGMX8]Y_XB[[>'CRO'\H*/EX%/KI?W@ZG']XVSE_
M%-+_?Z`"8>L@`)Q[%,H(?13B_W^(\/QXHO#G>.(N&7EX.X=_*"@:>2``O'MX
MRUI_>#K=?Q32_W\44DE]B/`:>7A"O7^B\`AY%.)*?2``O7MX0UQ_R"[H>^(N
M^GL4ZDI]%-HI?7C3'7UXXNA\%.I*?7CZ"'T@`-Y[%`(I?<@N77D4\BE]XBY;
M>2``'GFB\.![B/#H>Q3R*7UXV[]_>`,(?10R"'T46N=\%")*?10JO'P4^BE]
M(`!*>2``*7D@`.=X(`"F>"``"'D(`$/Y(`#C^```(_D8`,/X$``#^:@"0>GP
MCRWI>4I*?0``(#DL`()`\`(A.,#_`>O(_R'KT/]!Z]C_8>O@_X'KZ/^AZ_#_
MP>OX_^'K(`"`3J8""'P``P'XS;?_2Q@`0>@``````````8`(``````!@``!"
M8`(`3#S0%T(XI@((?(``8#@0``'XX?\A^)FZ_TL8`$'H``!`.<WOH#RZF,`\
MTL,`/7@`0Y%%9X`\B:NE8"@`0_G^W,9@,A#@/#``0_GPX0AA`2.$8"``I7@@
M`,9X=E3G8"``"'D``(/X"`"C^!``P_@@`"$X&`#C^"```_D0``'HI@,(?"``
M@$X``````````8````````!@````8```0F`"`$P\,!=".*8""'RX_^'ZX/^!
M^R0?J7CP_\'[^/_A^W@;?'Q"'ZAXV/]A^^C_H?MX*[]\.`#<.W@CEWP0``'X
M@?\A^"@`0^EX`&.`,`#\Z!12*7T```,L(``I>1!(2GT044I]*``\^5`X*GT4
M2@A],``<^>P`@D`_`!\LI`"!0"@`H?K`_[\Z,`#!^GB[_WZ^T;M60``!^T@`
M(?L0```[`0#;.E``0?L@`"`[>+/=?C``0#L```!@````8```0F"8_D!]F,9_
M??__O3MXXX-_F,Z??9C6'WQ``/\[F/=`?9C'?GV8SYY]F-<>?)WH_TL``!TL
MS/^"0,@WUGHR,']70``!ZT@`(>M0`$'K4*C_?Q2R]WXH`*'J,`#!ZK0'_W]X
MN^1^>//#?WC[Y7\%L_]+&`!!Z'@`_).``"$X$``!Z+C_X>K8_V'KX/^!Z^C_
MH>OP_\'K^/_AZZ8#"'P@`(!.0`"C(P`H'7Q8`(%!M`=C?+0'NW\4&GY\>-ME
M?WB[Y'ZQLO]+&`!!Z'@`/($42CU]0``)+'@`/)&@_X)`4/C]?WCC@W^T!_]_
M%-KW?MWG_TO(_O]+````8````&```$)@>"N]?+0'8WRT![M_%!I^?'C;97]X
MN^1^6;+_2Q@`0>AX`#R!%$H]?4``"2QX`#R12/^"0*C__TL``````````8`+
M``````!@````8```0F`"`$P\(!5".*8""'SH_Z'[\/_!^R@`!#GX_^'[V/]A
M^S@`I#N`_T`YX/^!^W@;?GQX(Y]\$``!^+'_(?@H`"3I+$2`?S``!#DL1&!_
MONXI50$`J3BT!RE].``%++0'HWRN25U]%!I]?&@!@4!``*4@``"`.+0'I7R)
MM?]+&`!!Z'C[XW_UYO]+C`,`$!``0#D@`"`Y````.58"@/%H`!_YF.^`?9A7
MG7V83YU]<`!_DW0`GY-X^^-_P>;_2P``/^EX^^-_`D8I>0``/ID``#_I`H0I
M>0$`/ID``#_I`L(I>0(`/ID``#_I`P`^F0@`/^D"1BEY!``^F0@`/^D"A"EY
M!0`^F0@`/^D"PBEY!@`^F0@`/^D'`#Z9$``_Z0)&*7D(`#Z9$``_Z0*$*7D)
M`#Z9$``_Z0+"*7D*`#Z9$``_Z0L`/ID8`#_I`D8I>0P`/ID8`#_I`H0I>0T`
M/ID8`#_I`L(I>0X`/ID8`#_I#P`^F2``/^D"1BEY$``^F2``/^D"A"EY$0`^
MF2``/^D"PBEY$@`^F2``/^D3`#Z9);'_2Q@`0>A0`"$X$``!Z-C_8>O@_X'K
MZ/^AZ_#_P>OX_^'KI@,(?"``@$X```!@``!"8#@`I2```(`XM`>E?"6T_TL8
M`$'HR/[_2P`````````!@`4``````&````!@````8`(`3#P@$T(XI@((?-C_
M8?O@_X'[>"N[?.C_H?OP_\'[___"/W@;?7SX_^'[___B/Z![WCNH>_\[>".<
M?%#X_G\0``'XL?\A^*&N_TL```!@=1[_?S``@D$8`$'X^/_>.PD`GNEXVV5_
M>..$?WCKHW^F`XE](02`3A@`0>C___\WX/^"0%``(3@0``'HV/]AZ^#_@>OH
M_Z'K\/_!Z_C_X>NF`PA\(`"`3@`````````!@`4``````&````!@``!"8"``
M@$X````````````````"`$P\4!)".*8""'P```!@"('"Z!```?CA_R'X-;/_
M2Q@`0>@@`"$X$``!Z*8#"'P@`(!.``````````&`````&)`!``````"F`@A\
M!0"?0J8":'VF`PA\\/\+Z%!@BWT46F!]U/\,.```B^F"\`!XI@.)?0@`:^D@
M!(!.S/__2\C__TO$__]+P/__2[S__TNX__]+M/__2[#__TNL__]+J/__2Z3_
M_TN@__]+G/__2YC__TN4__]+D/__2XS__TN(__]+A/__2X#__TM\__]+>/__
M2W3__TMP__]+;/__2VC__TMD__]+8/__2US__TM8__]+5/__2U#__TM,__]+
M2/__2T3__TM`__]+//__2SC__TLT__]+,/__2RS__TLH__]+)/__2R#__TL<
M__]+&/__2Q3__TL0__]+#/__2PC__TL$__]+`/__2_S^_TOX_O]+]/[_2_#^
M_TOL_O]+Z/[_2^3^_TL"`$P\Z!!".*8""'P0``'XH?\A^&``(3@0``'HI@,(
M?"``@$X``````0`"```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%27U1%
M35```````````%!!4E]04D]'3D%-10`````Z`````````"\`````````)7,E
M<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````````
M4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#
M3$5!3@````````!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!
M4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2````````
M`%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@``````````,0````````!,1%],24)205)97U!!5$@`4UE35$5-```E
M,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````4$%42`````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S
M)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8````````
M`'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U
M-0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````55-%
M4@````!54T523D%-10``````````5$U01$E2``!414U01$E2`%1%35``````
M5$U0```````O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N
M<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H
M<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H
M*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@
M)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M
M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@
M:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?
M<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@[
M"FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[
M(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S
M:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I
M8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M
M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P
M*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'
M24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S
M*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`T("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C
M:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*
M)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H
M+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]
M*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N
M86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U
M9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T
M97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@
M("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T[
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0II9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR
M96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@
M9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@[
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q
M6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H
M*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D
M871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D
M97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S
M?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@
M("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE
M+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F
M8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME
M>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>
M+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*
M;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN
M=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD
M=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*
M;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2![
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B
M)&]U=")=.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO
M<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D=&@I
M.PIC;&]S92`D=&@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#`@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B7#!#04-(12(["FUY("1O9F9S970@/2`D
M9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE7VYA;64I("T@;&5N9W1H*"1L;V%D
M97(I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`IP86-K*"=.)RP@)&]F9G-E
M="DL"B1005)?34%'24,I"B8F("1F:"T^8VQO<V4*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@
M)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P
M97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PHD<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIO=71S*")296%D:6YG($U%5$$N>6UL+BXN
M(BD["FEF("AM>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B1M971A(#U^(',O+BI><&%R.EQS*B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*:68@*&UY("@D8VQE86XI(#T@)&UE=&$@/7X@+UY<<RMC;&5A
M;CH@*"XJ*20O;2D@>PHD8VQE86X@/7X@+UY<<RI\7',J)"]G.PHD14Y6>U!!
M4E]#3$5!3GT@/2`Q(&EF("1C;&5A;CL*?0I]"G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO
M=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N
M86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L
M("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@
M+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@
M>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ
M<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA
M;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T
M>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF
M)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO
M9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N
M86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R
M;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]
M?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D
M,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%
M3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*
M?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F
M:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@
M,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI
M=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2![
M"G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*
M?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/
M1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@
M/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````1L#.^@`
M```<````C'/__^`%``#L=___&`$``#QY__^$`0``;'O__P`"```\?/__*`(`
M`(Q]__]T`@``C(#__]`"```\@?__]`(``*R!__\4`P``O(+__T0#``#<@O__
M6`,``#R'__\,!```?(?__R`$``#\B?__7`0``.R/__^8!```K)#__\@$``#\
MD/__Z`0``#R2__\@!0``K)W__V0%``#,H/__J`4``)RB__\(!@``?+C__T@&
M```<N?__:`8``"R[__^X!@``++W__^P&``#LO?__(`<``/R]__\T!P``1+[_
M_P`!```0``````````%Z4@`$>$$!&PP!`!0````8````/+W__R`!````0@E!
M`$(&06@````P````S';__U`!````0YP$0PY0GP%"FP5&F@9!G@)2"4$`09T#
M0Q%!?E+:0=M!W4'>009!00X`0]_<00Y0F@:;!9P$G0.>`I\!$4%^1MK;W=X&
M04*;!4';0IH&FP6>`D/:0=M!W@```'@```"<````L'?__R@"````1`ZP`IX"
M3@H.`$'>00M!"4$`09\!01%!?D6=`T&:!D*;!5><!&7<30K:0=M!W4'?009!
M1`M(VMO=0M]!!D%!F@:;!9P$G0.?`1%!?D+:V]S=WP9!00E!`$&:!D&;!4&<
M!$&=`T&?`4$107XD````&`$``&1Y___$`````$0)00"?`4,.T`$107YA"@X`
M0P9!WT$+2````$`!```,>O__4`$```!'"4$`G0.>`I\!1@[0(!%!?DJ<!%L*
MW$(+0=Q/#@!%!D'?WMU##M`@G`2=`YX"GP$107Y"W$&<!````%@```",`0``
M$'O___0"````1PE!`)P$G0.>`I\!10ZP`9H&FP4107X"3PH.`$@&0=_>W=S;
MVD$+49@(09D';`K80=E!"TK8V4*8")D'0]C909@(09D'0]A!V0``(````.@!
M``"T??__K`````!$"4$`GP%$#C`107Y<#@!#!D'?'`````P"``!`?O__9```
M``!'#B`107Y,#@!"!D$````L````+`(``)!^__\$`0```$4)00"=`YX"1`Z@
M09\!$4%^;`H.`$8&0=_>W4$+```0````7`(``'!___\8`````````+````!P
M`@``?'___U@$````10E!`)D'G0-%G@*?`4,107Y##H`C$4=_$4A_1@5L$%0*
M#@!(!D%!!D=!!DC?WMW9!FQ$"T*:!D&;!4^5"T&6"D.7"4&8"$63#4&4#$*<
M!`);"M-!U$'50=9!UT'80=I!VT'<0@MB"M-!U$'50=9!UT'80=I!VT'<0@M=
MT]35UM?8W$':0=M"DPU!E`Q!E0M!E@I!EPE!F`A!F@9!FP5!G`0``!`````D
M`P``*(/__SP`````````.````#@#``!4@___?`(```!$"4$`GP%##C`107X"
M=PH.`$,&0=]!"T<*#@!#!D'?00M+#@!#!D'?````.````'0#``"8A?__[`4`
M``!%"4$`G@*?`4@.H`&:!IL%G`2=`Q%!?@-7`0H.`$@&0=_>W=S;VD$+````
M+````+`#``!,B___P`````!%#G!,"@X`0PM!"4$`1!%!?D\&04()00!!$4%^
M````'````.`#``#<B___3`````!%#B`107Y(#@!"!D$````T``````0```R,
M__\X`0```$4)00"=`YX"1PZ0`9\!$4%^4PH.`$4&0=_>W40+1IP$6=Q"G`0`
M`$`````X!```%(W__VP+````50E!`)H&FP6=`Y\!EPF8")D'G`2>`D0107Y-
M#H"$`@*@"@X`3`9!W][=W-O:V=C70@L`0````'P$``!`F/__(`,```!&"4$`
MG0.>`I\!1`Z0`1%!?G^<!$[<<`H.`$4&0=_>W40+3IP$3]Q,"IP$20M!G`0`
M```T````P`0``!R;___$`0```$4)00">`I\!0PZ``1%!?G8*#@!$!D'?WD(+
M7`H.`$4&0=_>00L``"0```#X!```I&W__\@"````2`Z@`1%!?IX"GP$"=@H.
M`$0&0=_>00L\````(`4``(R<___8%0```$P.\`68")D'F@:;!9P$G0.>`I\!
M`UH%"@X`2-_>W=S;VMG800M!"4$`01%!?@``'````&`%```LLO__E`````!&
M#B`107Y7#@!$!D$```!,````@`4``*RR__\$`@```$@)00"7"9P$G@*?`4D.
M@`&;!9T#$4%^4)4+0I8*0Y@(09D'0YH&5]A!V4':0]5!UD@*#@!(!D'?WMW<
MV]=!"S````#0!0``;+3___0!````2`E!`)T#G@*?`9L%1PY0G`0107X"6PH.
M`$<&0=_>W=S;0PLP````!`8``#BV__^T`````$4)00";!9P$0YT#G@)#GP%'
M#E`107Y0#@!'!D'?WMW<VP``$````#@&``#$MO__$``````````<````3`8`
M`,"V__]``````$<.(!%!?D,.`$(&00``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````"0)@```````"`F
M``````````````````!`(@```````.!K````````H&P````````!````````
M`.P"`````````0````````#\`@````````$`````````#`,````````,````
M`````,`:````````#0`````````8;@```````!D`````````H/H!```````;
M``````````@`````````&@````````"H^@$``````!P`````````"```````
M``#U_O]O`````)`"````````!0````````#0#`````````8`````````<`,`
M```````*`````````'0$````````"P`````````8`````````!4`````````
M```````````#`````````!C]`0```````@````````"(!0```````!0`````
M````!P`````````7```````````5````````````<``````,;0````````,`
M`'`````````````````'`````````&`2````````"`````````"@`@``````
M``D`````````&``````````>``````````@`````````^___;P`````!```(
M`````/[__V\`````$!(```````#___]O``````(`````````\/__;P````!$
M$0```````/G__V\`````$0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M`+#Z`0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````"``"``````#_____`````/!Q````
M````L&X``````````````````*!O````````T'$```````#8<0```````.!Q
M````````Z'$``````````````````+AQ````````P'$`````````````````
M`/AQ````````1T-#.B`H1&5B:6%N(#$Q+C,N,"TT*2`Q,2XS+C```"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````.`(````````X`@```````!$````````````````````!````
M````````````````$P````<````"`````````$P"````````3`(````````D
M````````````````````!````````````````````"8````'`````@``````
M``!P`@```````'`"````````(`````````````````````0`````````````
M```````T````]O__;P(`````````D`(```````"0`@```````.``````````
M!0`````````(````````````````````/@````L````"`````````'`#````
M````<`,```````!@"0````````8````#````"``````````8`````````$8`
M```#`````@````````#0#````````-`,````````=`0`````````````````
M``$```````````````````!.````____;P(`````````1!$```````!$$0``
M`````,@`````````!0`````````"``````````(`````````6P```/[__V\"
M`````````!`2````````$!(```````!0``````````8````"````"```````
M`````````````&H````$`````@````````!@$@```````&`2````````H`(`
M```````%``````````@`````````&`````````!T````!````$(`````````
M`!4`````````%0```````(@%````````!0```!8````(`````````!@`````
M````?@````$````&`````````*`:````````H!H```````!<````````````
M````````(````````````````````(0````!````!@``````````&P``````
M```;````````&%,``````````````````"````````````````````"*````
M`0````8`````````&&X````````8;@```````"0````````````````````$
M````````````````````D`````$````"`````````$!N````````0&X`````
M``!R0```````````````````"````````````````````)@````!`````@``
M``````"TK@```````+2N````````[`````````````````````0`````````
M``````````"F`````0````(`````````H*\```````"@KP```````&P&````
M```````````````$````````````````````L`````X````#`````````*#Z
M`0``````H/H````````(````````````````````"``````````(````````
M`+P````/`````P````````"H^@$``````*CZ````````"```````````````
M``````@`````````"`````````#(`````0````,`````````L/H!``````"P
M^@```````"`````````````````````(````````````````````U0````8`
M```#`````````-#Z`0``````T/H````````P`@````````8`````````"```
M```````0`````````-X````!`````P``````````_P$```````#_````````
M:``````````````````````!````````"`````````!Y````"`````,`````
M````&/T!````````_0```````.@!```````````````````(``````````@`
M````````XP````$````#`````````````@`````````!``````"`````````
M````````````"````````````````````.D````(`````P````````"```(`
M`````(```0``````*!````````````````````@```````````````````#N
M`````0```#````````````````````"```$``````!X`````````````````
M```!``````````$``````````0````,`````````````````````````G@`!
E``````#W`````````````````````0``````````````````````
